@@ -1,29 +1,21 @@
-#' http lib adapter registry
-#'
+#' @title HttpLibAdapaterRegistry
+#' @description http lib adapter registry
 #' @export
-#' @details
-#' **Methods**
-#'   \describe{
-#'     \item{`register(x)`}{
-#'       Register an http library adapter
-#'       x: an http lib adapter, e.g., [CrulAdapter]
-#'       return: nothing, registers the library adapter
-#'     }
-#'   }
-#' @format NULL
-#' @usage NULL
 #' @examples
 #' x <- HttpLibAdapaterRegistry$new()
 #' x$register(CrulAdapter$new())
 #' x
 #' x$adapters
 #' x$adapters[[1]]$name
-
 HttpLibAdapaterRegistry <- R6::R6Class(
   'HttpLibAdapaterRegistry',
   public = list(
+    #' @field adapters list
     adapters = NULL,
 
+    #' @description print method for the `HttpLibAdapaterRegistry` class
+    #' @param x self
+    #' @param ... ignored
     print = function(x, ...) {
       cat("<HttpLibAdapaterRegistry> ", sep = "\n")
       for (i in seq_along(self$adapters)) {
@@ -32,9 +24,12 @@ HttpLibAdapaterRegistry <- R6::R6Class(
       }
     },
 
+    #' @description Register an http library adapter
+    #' @param x an http lib adapter, e.g., [CrulAdapter]
+    #' @return nothing, registers the library adapter
     register = function(x) {
       # FIXME: when other adapters supported, change this inherits test
-      if (!inherits(x, c("CrulAdapter", "HttrAdapter"))) {
+      if (!inherits(x, c("CrulAdapter", "HttrAdapter", "Httr2Adapter"))) {
         stop("'x' must be an adapter, such as CrulAdapter", call. = FALSE)
       }
       self$adapters <- c(self$adapters, x)
