@@ -1,14 +1,16 @@
 context("request_registry")
 
 test_that("request_registry: structure", {
+  request_registry_clear()
+
   expect_is(request_registry, "function")
   expect_is(request_registry(), "RequestRegistry")
 
   enable()
-  stub_request("get", "https://httpbin.org/get") %>%
+  stub_request("get", hb("/get")) %>%
     to_return(body = "success!", status = 200)
   invisible(
-    crul::HttpClient$new(url = "https://httpbin.org")$get("get")
+    crul::HttpClient$new(url = hb())$get("get")
   )
   disable()
 
@@ -23,5 +25,5 @@ test_that("request_registry: structure", {
 
   expect_is(x$request_signatures$hash, "list")
   expect_match(names(x$request_signatures$hash), "GET")
-  expect_is(x$request_signatures$hash[[1]], 'numeric')
+  expect_is(x$request_signatures$hash[[1]]$count, 'numeric')
 })
