@@ -7,7 +7,7 @@ test_that("no stubs exist before stub_request called", {
 })
 
 library(fauxpas)
-aa <- stub_request("get", "https://httpbin.org/get") %>% to_raise(HTTPAccepted)
+aa <- stub_request("get", hb("/get")) %>% to_raise(HTTPAccepted)
 
 test_that("stub_request bits are correct", {
 
@@ -18,20 +18,20 @@ test_that("stub_request bits are correct", {
   expect_null(aa$query)
   expect_null(aa$request_headers)
   expect_null(aa$response_headers)
-  expect_null(aa$responses_sequences)
-  expect_false(aa$timeout)
+  # expect_false(aa$timeout) # timeout will be removed in StubbedRequest
 
   expect_is(aa$method, "character")
   expect_equal(aa$method, "get")
   expect_is(aa$uri, "character")
-  expect_equal(aa$uri, "https://httpbin.org/get")
+  expect_equal(aa$uri, hb("/get"))
 
   # to_raise expected stuff
-  expect_true(aa$raise)
-  expect_is(aa$exceptions, "list")
-  expect_is(aa$exceptions[[1]], "R6ClassGenerator")
-  expect_equal(aa$exceptions[[1]]$classname, "HTTPAccepted")
-  expect_equal(aa$exceptions[[1]]$new()$status_code, 202)
+  rr <- aa$responses_sequences[[1]]
+  expect_true(rr$raise)
+  expect_is(rr$exceptions, "list")
+  expect_is(rr$exceptions[[1]], "R6ClassGenerator")
+  expect_equal(rr$exceptions[[1]]$classname, "HTTPAccepted")
+  expect_equal(rr$exceptions[[1]]$new()$status_code, 202)
 })
 
 test_that("stubs exist after stub_request called", {
@@ -43,7 +43,7 @@ test_that("stub_request fails well", {
   expect_error(to_raise(5), ".data must be of class StubbedRequest")
 
   # exception clases
-  zzz <- stub_request("get", "https://httpbin.org/get")
+  zzz <- stub_request("get", hb("/get"))
   expect_error(to_raise(zzz, "foo"),
                "all objects must be error classes from fauxpas")
 })
